@@ -15,12 +15,14 @@ class TestImagingReaders(unittest.TestCase):
     imaging_dir = RESOURCES_DIR / "imaging"
     exaspim_dir = imaging_dir / "exaSPIM_125L_2022-08-05_17-25-36"
     mesospim_dir = imaging_dir / "mesoSPIM_125L_2022-08-18_17-05-00"
+    dispim_dir = imaging_dir / "diSPIM_12345_2023-03-16_00-00-00"
     generic_dir = imaging_dir / "12345-random-sample"
 
     @parameterized.expand(
         [
             (ImagingReaders.Readers.exaspim.value, exaspim_dir),
             (ImagingReaders.Readers.mesospim.value, mesospim_dir),
+            (ImagingReaders.Readers.dispim.value, dispim_dir),
             (ImagingReaders.Readers.generic.value, generic_dir),
         ]
     )
@@ -33,6 +35,7 @@ class TestImagingReaders(unittest.TestCase):
         [
             ImagingReaders.Readers.exaspim.value,
             ImagingReaders.Readers.mesospim.value,
+            ImagingReaders.Readers.dispim.value,
             ImagingReaders.Readers.generic.value
         ]
     )
